@@ -10,10 +10,10 @@ import dna.FastaToChromArrays2;
 import fileIO.ReadWrite;
 import shared.Parse;
 import shared.PreParser;
-import shared.ReadStats;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
+import tracker.ReadStats;
 
 /**
  * @author Brian Bushnell
